#ifndef NT2_INCLUDE_FUNCTIONS_COSINE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_COSINE_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/cosine.hpp>

#endif
